from dialog_api.messaging_pb2 import LISTLOADMODE_UNKNOWN, LISTLOADMODE_FORWARD, LISTLOADMODE_BACKWARD, LISTLOADMODE_BOTH


class ListLoadMode:
    LISTLOADMODE_UNKNOWN = LISTLOADMODE_UNKNOWN
    LISTLOADMODE_FORWARD = LISTLOADMODE_FORWARD
    LISTLOADMODE_BACKWARD = LISTLOADMODE_BACKWARD
    LISTLOADMODE_BOTH = LISTLOADMODE_BOTH
