class UserStatus:
    USERSTATUSTYPE_UNKNOWN = 0
    USERSTATUSTYPE_UNSET = 1
    USERSTATUSTYPE_AWAY = 2
    USERSTATUSTYPE_DONOTDISTURB = 3
    USERSTATUSTYPE_INVISIBLE = 4
    USERSTATUSTYPE_BUSY = 5