import unittest

from tests.test_updates import TestUpdates
from tests.test_users import TestUsers
from tests.test_groups import TestGroups
from tests.test_bot import TestBot
from tests.test_messaning import TestMessaging

if __name__ == '__main__':
    unittest.main()
